[binutils-gdb] [gdb] Fix typos

Tom de Vries via Gdb-cvs <[email protected]> Mon, 15 Jun 2026 11:24:26 +0000 (GMT)
Newsgroups gmane.comp.gdb.cvs
Message-ID <[email protected]>
https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=ffc165129b235da06f09c0eeba3a7552c05667c1

commit ffc165129b235da06f09c0eeba3a7552c05667c1
Author: Tom de Vries <[email protected]>
Date:   Mon Jun 15 13:24:08 2026 +0200

    [gdb] Fix typos
    
    Fix typos in the gdb dir.

Diff:
---
 gdb/arm-linux-nat.c  | 2 +-
 gdb/buildsym.c       | 6 +++---
 gdb/buildsym.h       | 2 +-
 gdb/infrun.c         | 2 +-
 gdb/infrun.h         | 2 +-
 gdb/loongarch-tdep.c | 2 +-
 gdb/ppc-linux-tdep.c | 4 ++--
 gdb/windows-nat.c    | 6 +++---
 gdb/xcoffread.c      | 2 +-
 gdb/z80-tdep.c       | 2 +-
 10 files changed, 15 insertions(+), 15 deletions(-)

diff --git a/gdb/arm-linux-nat.c b/gdb/arm-linux-nat.c
index 007d8d74eb6..02251e9fa48 100644
--- a/gdb/arm-linux-nat.c
+++ b/gdb/arm-linux-nat.c
@@ -711,7 +711,7 @@ struct arm_linux_hw_breakpoint
    for caching address and control information.
 
    The Linux ptrace interface to hardware break-/watch-points presents the
-   values in a vector centred around 0 (which is used fo generic information).
+   values in a vector centred around 0 (which is used for generic information).
    Positive indices refer to breakpoint addresses/control registers, negative
    indices to watchpoint addresses/control registers.
 
diff --git a/gdb/buildsym.h b/gdb/buildsym.h
index c9010665bce..c46f75e6511 100644
--- a/gdb/buildsym.h
+++ b/gdb/buildsym.h
@@ -218,7 +218,7 @@ struct buildsym_compunit
     m_producer = producer;
   }
 
-  void push_context (CORE_ADDR valu);
+  void push_context (CORE_ADDR value);
 
   /* Pop a context and create the corresponding block.  Returns the
      block.  END_ADDR is the final address of the block.  STATIC_LINK,
diff --git a/gdb/infrun.c b/gdb/infrun.c
index 22a05608486..00bedc7b6ae 100644
--- a/gdb/infrun.c
+++ b/gdb/infrun.c
@@ -7006,7 +7006,7 @@ handle_signal_stop (struct execution_control_state *ecs)
 
 	  std::string addr_str;
 	  if (addr_list.empty ())
-	    addr_str = "(no data addressses available)";
+	    addr_str = "(no data addresses available)";
 	  else
 	    {
 	      for (const CORE_ADDR addr : addr_list)
diff --git a/gdb/infrun.h b/gdb/infrun.h
index 42c867ce303..cbc603b74ed 100644
--- a/gdb/infrun.h
+++ b/gdb/infrun.h
@@ -129,7 +129,7 @@ extern void start_remote (int from_tty);
    continued or stepped.  First do this, then set the ones you want,
    then call `proceed'.  STEP indicates whether we're preparing for a
    step/stepi command.  Set ABOUT_TO_PROCEED to false if we're not
-   calling `proceeed` yet.  */
+   calling `proceed` yet.  */
 extern void clear_proceed_status (int step, bool about_to_proceed = true);
 
 extern void proceed (CORE_ADDR, enum gdb_signal);
diff --git a/gdb/loongarch-tdep.c b/gdb/loongarch-tdep.c
index 999fd6a864d..1eeebbd562f 100644
--- a/gdb/loongarch-tdep.c
+++ b/gdb/loongarch-tdep.c
@@ -734,7 +734,7 @@ loongarch_frame_prev_register (const frame_info_ptr &this_frame,
 
   /* If we are asked to unwind the PC, then we need to return the RA
      instead.  The prologue may save PC, but it will point into this
-     frame's prologue, not the previou frame's resume location.  */
+     frame's prologue, not the previous frame's resume location.  */
   if (regnum == LOONGARCH_PC_REGNUM)
     {
       CORE_ADDR ra;
diff --git a/gdb/ppc-linux-tdep.c b/gdb/ppc-linux-tdep.c
index 19698eaacbe..07969454b39 100644
--- a/gdb/ppc-linux-tdep.c
+++ b/gdb/ppc-linux-tdep.c
@@ -574,7 +574,7 @@ static const struct regset ppc32_linux_vsxregset = {
   regcache_collect_regset
 };
 
-/* Program Priorty Register regmap.  */
+/* Program Priority Register regmap.  */
 
 static const struct regcache_map_entry ppc32_regmap_ppr[] =
   {
@@ -582,7 +582,7 @@ static const struct regcache_map_entry ppc32_regmap_ppr[] =
       { 0 }
   };
 
-/* Program Priorty Register regset.  */
+/* Program Priority Register regset.  */
 
 const struct regset ppc32_linux_pprregset = {
   ppc32_regmap_ppr,
diff --git a/gdb/windows-nat.c b/gdb/windows-nat.c
index 8487ea41b73..1ee782b242a 100644
--- a/gdb/windows-nat.c
+++ b/gdb/windows-nat.c
@@ -132,7 +132,7 @@ the process.  In fact, it seldom is.  E.g., if the main thread calls
 ExitProcess (or returns from main, which ends up calling ExitProcess),
 then we typically see a EXIT_THREAD_DEBUG_EVENT event for the main
 thread first, followed by more EXIT_THREAD_DEBUG_EVENT events for
-other threads, and then finaly the EXIT_PROCESS_DEBUG_EVENT for
+other threads, and then finally the EXIT_PROCESS_DEBUG_EVENT for
 whatever thread happened to be the last one to exit.
 
 When a thread reports EXIT_THREAD_DEBUG_EVENT /
@@ -258,7 +258,7 @@ wants the "sig" thread to be running.
 This isn't ideal, since this means that with user-visible non-stop,
 the inferior will only be able to process and report one signal at a
 time (as the "sig" thread is responsible for that), but that seems
-like an acceptible compromise, better than not being able to have the
+like an acceptable compromise, better than not being able to have the
 target work in non-stop by default on Cygwin.  */
 
 using namespace windows_nat;
@@ -1268,7 +1268,7 @@ windows_nat_target::stop_one_thread (windows_thread_info *th,
 	      stop and calls windows_continue on this thread.  */
 	   && stopping_kind == SK_EXTERNAL)
     {
-      DEBUG_EVENTS ("explict stop for \"sig\" thread %s held for signal",
+      DEBUG_EVENTS ("explicit stop for \"sig\" thread %s held for signal",
 		    thr_ptid.to_string ().c_str ());
 
       th->stopping = stopping_kind;
diff --git a/gdb/xcoffread.c b/gdb/xcoffread.c
index 73662c47c3d..08d5d810c6f 100644
--- a/gdb/xcoffread.c
+++ b/gdb/xcoffread.c
@@ -235,7 +235,7 @@ xcoff_get_toc_offset (objfile *objfile)
   return 0;
 }
 
-/* This function is used to read minimal sysmbols from the XCOFF STABS
+/* This function is used to read minimal symbols from the XCOFF STABS
    symbol table. This function needs to be called when a library (like
    libc) in AIX is compiled using xlc whose debug format is STABS.
    When STABS debug information is not available, then in the backtrace
diff --git a/gdb/z80-tdep.c b/gdb/z80-tdep.c
index 3a0d5f7e393..9da18855d71 100644
--- a/gdb/z80-tdep.c
+++ b/gdb/z80-tdep.c
@@ -1427,7 +1427,7 @@ z80_get_insn_info (struct gdbarch *gdbarch, const gdb_byte *buf, int *size)
 	case insn_adl:
 	  info = &ez80_adl_main_insn_table[0];
 	  break;
-	/*  These two (for GameBoy Z80 & Z80 Next CPUs) haven't been tested.
+	/*  These two (for Game Boy Z80 & Z80 Next CPUs) haven't been tested.
 
 	case bfd_mach_gbz80:
 	  info = &gbz80_main_insn_table[0];
diff --git a/gdb/buildsym.c b/gdb/buildsym.c
index 9799af17f32..94bc5a24edb 100644
--- a/gdb/buildsym.c
+++ b/gdb/buildsym.c
@@ -924,15 +924,15 @@ buildsym_compunit::augment_type_symtab ()
     }
 }
 
 /* Push a context block.  VALU is the starting PC address of this
    context.  */
 
 void
-buildsym_compunit::push_context (CORE_ADDR valu)
+buildsym_compunit::push_context (CORE_ADDR value)
 {
   m_context_stack.emplace_back (std::move (m_local_symbols),
 				m_local_using_directives,
-				m_pending_blocks, valu);
+				m_pending_blocks, value);
   m_local_using_directives = nullptr;
 }
 
@@ -924,15 +924,15 @@ buildsym_compunit::augment_type_symtab ()
 }
 
-/* Push a context block.  VALU is the starting PC address of this
+/* Push a context block.  VALUE is the starting PC address of this
    context.  */
 